@@ -5,6 +5,7 @@
 // License: Mozilla Public License v2.0 (MPL v2.0)
 
 use futures::{future, Future};
+use log::{error, info};
 use std::collections::BTreeMap;
 use std::io::{Error, ErrorKind};
 use std::time::Duration;
@@ -19,7 +20,7 @@ use trust_dns_server::server::ServerFuture;
 use super::handler::DNSHandler;
 use crate::APP_CONF;
 
-lazy_static! {
+lazy_static::lazy_static! {
     static ref NAME_SOA_MASTER: Name =
         Name::parse(&APP_CONF.dns.soa_master, Some(&Name::new())).expect("invalid soa master");
     static ref NAME_SOA_RESPONSIBLE: Name =
@@ -53,7 +54,7 @@ impl DNSListen {
         let mut runtime = Runtime::new().expect("error when creating dns listen runtime");
         let server = ServerFuture::new(handler);
 
-        let server_future: Box<Future<Item = (), Error = ()> + Send> =
+        let server_future: Box<dyn Future<Item = (), Error = ()> + Send> =
             Box::new(future::lazy(move || {
                 // Register sockets & listeners
                 for inet in &APP_CONF.dns.inets {
