@@ -5,8 +5,6 @@
 // License: Mozilla Public License v2.0 (MPL v2.0)
 
 use regex::Regex;
-use rocket::http::RawStr;
-use rocket::request::FromParam;
 use serde::de::{Error as DeserializeError, Unexpected, Visitor};
 use serde::{Deserialize, Deserializer, Serialize, Serializer};
 use std::cmp;
@@ -22,14 +20,14 @@ use trust_dns::rr::{
 
 use crate::geo::country::CountryCode;
 
-lazy_static! {
+lazy_static::lazy_static! {
     static ref RECORD_NAME_REGEX: Regex = Regex::new(r"^(\*\.)?(([^\\/:@&\*]+)\.)?@$").unwrap();
 }
 
 static DATA_TXT_CHUNK_MAXIMUM: usize = 255;
 
-serde_string_impls!(RecordType);
-serde_string_impls!(RecordName);
+serde_string_impls!(RecordType, from_str);
+serde_string_impls!(RecordName, from_str);
 
 #[derive(Clone, Debug, Eq, PartialEq, Hash)]
 pub enum RecordType {
@@ -296,19 +294,3 @@ impl Deref for RecordValue {
         &self.0
     }
 }
-
-impl<'r> FromParam<'r> for RecordType {
-    type Error = &'r RawStr;
-
-    fn from_param(param: &'r RawStr) -> Result<Self, Self::Error> {
-        RecordType::from_str(param).ok_or(param)
-    }
-}
-
-impl<'r> FromParam<'r> for RecordName {
-    type Error = &'r RawStr;
-
-    fn from_param(param: &'r RawStr) -> Result<Self, Self::Error> {
-        RecordName::from_str(param).ok_or(param)
-    }
-}
