@@ -5,8 +5,6 @@
 // License: Mozilla Public License v2.0 (MPL v2.0)
 
 use regex::Regex;
-use rocket::http::RawStr;
-use rocket::request::FromParam;
 use serde::de::{Error as DeserializeError, Unexpected, Visitor};
 use serde::{Deserialize, Deserializer, Serialize, Serializer};
 use std::{fmt, str};
@@ -14,15 +12,17 @@ use trust_dns::rr::LowerName as TrustLowerName;
 
 use crate::APP_CONF;
 
-lazy_static! {
+lazy_static::lazy_static! {
     static ref ZONE_NAME_REGEX: Regex =
         Regex::new(r"^(([^\\/:@&_\*]+)\.)[^\\/:@&_\*\-\.]{2,63}$").unwrap();
 }
 
-serde_string_impls!(ZoneName);
+serde_string_impls!(ZoneName, from_str);
+serde_string_impls!(ZoneNameExists, from_str);
 
 #[derive(Clone, Debug, Eq, PartialEq, Hash)]
 pub struct ZoneName(String);
+pub struct ZoneNameExists(ZoneName);
 
 impl ZoneName {
     pub fn from_str(value: &str) -> Option<ZoneName> {
@@ -66,10 +66,16 @@ impl ZoneName {
     }
 }
 
-impl<'r> FromParam<'r> for ZoneName {
-    type Error = &'r RawStr;
+impl ZoneNameExists {
+    pub fn from_str(value: &str) -> Option<ZoneNameExists> {
+        ZoneName::from_str_exists(value).map(|zone_name| ZoneNameExists(zone_name))
+    }
 
-    fn from_param(param: &'r RawStr) -> Result<Self, Self::Error> {
-        ZoneName::from_str_exists(param).ok_or(param)
+    pub fn to_str(&self) -> &str {
+        &self.0.to_str()
+    }
+
+    pub fn into_inner(self) -> ZoneName {
+        self.0
     }
 }
