@@ -4,6 +4,7 @@
 // Copyright: 2019, Valerian Saliou <valerian@valeriansaliou.name>
 // License: Mozilla Public License v2.0 (MPL v2.0)
 
+use log::debug;
 use std::collections::HashMap;
 use std::sync::RwLock;
 use std::time::SystemTime;
@@ -12,7 +13,7 @@ use super::store::StoreRecord;
 use crate::APP_CONF;
 use crate::APP_STORE;
 
-lazy_static! {
+lazy_static::lazy_static! {
     pub static ref STORE_CACHE: StoreCache = StoreCacheBuilder::new();
 }
 
