@@ -4,6 +4,7 @@
 // Copyright: 2018, Valerian Saliou <valerian@valeriansaliou.name>
 // License: Mozilla Public License v2.0 (MPL v2.0)
 
+use log::{debug, error, info, warn};
 use r2d2::Pool;
 use r2d2_redis::RedisConnectionManager;
 use redis::{Commands, ErrorKind, RedisError};
@@ -122,7 +123,7 @@ impl StoreBuilder {
         // Establish pool connection for this Redis target
         match Self::pool_connect(host, port, password) {
             Ok(master_pool) => pools.push(master_pool),
-            Err(err) => panic!(err),
+            Err(err) => panic!("store error: {}", err),
         }
     }
 
